import React from 'react';
import { View, Text, FlatList, Button } from 'react-native';
import { useNavigation } from '@react-navigation/native';
import Styles from '../styles/Style';
import Icon from 'react-native-vector-icons/MaterialIcons';


const itemsInBasket = [
  { id: 1, name: 'Product 1', price: 10.0 },
  { id: 2, name: 'Product 2', price: 20.0 },
  { id: 3, name: 'Product 3', price: 15.0 },
];

function BasketScreen() {
  const navigation = useNavigation();

  const calculateTotalPrice = () => {
    return itemsInBasket.reduce((total, item) => total + item.price, 0).toFixed(2);
  };

  const renderItem = ({ item }) => (
    <View style={Styles.itemRow}>
      <Text>{item.name}</Text>
      <Text>{item.price.toFixed(2)} €</Text>
    </View>
  );

  return (
    <View style={Styles.container}>
      <Text style={Styles.title}><Icon name="shopping-basket" size={19} color="black" style={Styles.basketIcon} /> Basket </Text>
      <FlatList
        data={itemsInBasket}
        renderItem={renderItem}
        keyExtractor={(item) => item.id.toString()}
      />
      <View style={Styles.totalPriceContainer}>
        <Text style={Styles.totalText}>Total:</Text>
        <Text style={Styles.totalText}>{calculateTotalPrice()} €</Text>
      </View>
      <Button
          title="Pay"
          onPress={() => navigation.navigate('Checkout', { totalPrice: calculateTotalPrice() })}
      />
    </View>
  );
}

export default BasketScreen;
